=======
Credits
=======

Author
------

* Aaron O'Mullan <aaron.omullan@friendco.de>

Fork maintainer
----------------

* Iacopo Spalletti <i.spalletti@nephila.it>

Contributors
------------

* Alex Koshelev
* Craig Tracey
* Daniel Lenski
* Dennis Schwertel
* John Vandenberg
* nooperpudd
* Tony Osibov
